@@ -7,10 +7,12 @@ import json
 from datetime import datetime
 from uuid import UUID
 from google.protobuf.json_format import MessageToJson
+import sys
 
 from indykite_sdk.utils.hash_methods import encrypt_bcrypt, encrypt_sha256
 from indykite_sdk.identity import IdentityClient
 from indykite_sdk.config import ConfigClient
+from indykite_sdk.authorization import AuthorizationClient
 from indykite_sdk.indykite.config.v1beta1.model_pb2 import (SendGridProviderConfig, MailJetProviderConfig, AmazonSESProviderConfig, MailgunProviderConfig)
 from indykite_sdk.indykite.config.v1beta1.model_pb2 import (EmailServiceConfig, AuthFlowConfig, OAuth2ClientConfig, IngestMappingConfig)
 from indykite_sdk.indykite.config.v1beta1.model_pb2 import OAuth2ProviderConfig, OAuth2ApplicationConfig
@@ -19,7 +21,9 @@ from indykite_sdk.indykite.identity.v1beta2.import_pb2 import PasswordCredential
 from indykite_sdk.indykite.config.v1beta1.model_pb2 import EmailAttachment, Email, EmailMessage, EmailTemplate, EmailDefinition
 from indykite_sdk.indykite.config.v1beta1.model_pb2 import google_dot_protobuf_dot_wrappers__pb2 as wrappers
 from indykite_sdk.indykite.identity.v1beta2.import_pb2 import Email as EmailIdentity
-
+from indykite_sdk.model.is_authorized import IsAuthorizedResource
+from indykite_sdk.model.tenant import Tenant
+import logging
 
 class ParseKwargs(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):  # pragma: no cover
@@ -455,10 +459,39 @@ Property ID and value of the property where the value is a reference
     import_digital_twins_update_parser.add_argument("id", help="Digital Twin id (gid)")
     import_digital_twins_update_parser.add_argument("tenant_id", help="Tenant id (gid)")
 
+    # is_authorized_dt
+    is_authorized_dt_parser = subparsers.add_parser("is_authorized_dt")
+    is_authorized_dt_parser.add_argument("digital_twin_id", help="Digital Twin id (gid)")
+    is_authorized_dt_parser.add_argument("tenant_id", help="Tenant id (gid)")
+
+    # is_authorized_token
+    is_authorized_token_parser = subparsers.add_parser("is_authorized_token")
+    is_authorized_token_parser.add_argument("access_token")
+
+    # is_authorized_property
+    is_authorized_property_parser = subparsers.add_parser("is_authorized_property")
+    is_authorized_property_parser.add_argument("property_type", help="Digital Twin Identity Property")
+    is_authorized_property_parser.add_argument("property_value", help="Digital Twin Identity Property value")
+
+    # create_consent
+    create_consent_parser = subparsers.add_parser("create_consent")
+    create_consent_parser.add_argument("pii_processor_id", help="ID of OAuth2 Application")
+    create_consent_parser.add_argument("pii_principal_id", help="DigitalTwin Id (gid)")
+
+    # list_consents
+    list_consents_parser = subparsers.add_parser("list_consents")
+    list_consents_parser.add_argument("pii_principal_id", help="DigitalTwin Id (gid)")
+
+    # revoke_consent
+    revoke_consent_parser = subparsers.add_parser("revoke_consent")
+    revoke_consent_parser.add_argument("pii_principal_id", help="DigitalTwin Id (gid)")
+    revoke_consent_parser.add_argument("consent_ids", nargs='*', help="List of consent ids separated by space")
+
     args = parser.parse_args()
     local = args.local
     client = IdentityClient(local)
     client_config = ConfigClient(local)
+    client_authorization = AuthorizationClient(local)
 
     command = args.command
 
@@ -687,8 +720,9 @@ Property ID and value of the property where the value is a reference
     elif command == "tenant_id":
         tenant_id = args.tenant_id
         tenant = client_config.get_tenant_by_id(tenant_id)
-        if tenant:
-            print_response(tenant)
+        logger = logging.getLogger()
+        if tenant and isinstance(tenant, Tenant):
+                print_response(tenant)
         else:
             print("Invalid tenant id")
 
@@ -1624,6 +1658,74 @@ Property ID and value of the property where the value is a reference
             print("Invalid import digital twins response")
         return import_digital_twins_config_response
 
+    elif command == "is_authorized_dt":
+        digital_twin_id = args.digital_twin_id
+        tenant_id = args.tenant_id
+        resources = [IsAuthorizedResource("resourceID", "LabelName"), IsAuthorizedResource("resource2ID", "LabelName")]
+        actions = ["ACTION"]
+        is_authorized = client_authorization.is_authorized_digital_twin(digital_twin_id, tenant_id, resources, actions)
+
+        if is_authorized:
+            print_response(is_authorized)
+        else:
+            print("Invalid is_authorized")
+        return is_authorized
+
+    elif command == "is_authorized_token":
+        access_token = args.access_token
+        resources = [IsAuthorizedResource("resourceID", "LabelName"), IsAuthorizedResource("resource2ID", "LabelName")]
+        actions = ["ACTION"]
+        is_authorized = client_authorization.is_authorized_token(access_token, resources, actions)
+        if is_authorized:
+            print_response(is_authorized)
+        else:
+            print("Invalid is_authorized")
+        return is_authorized
+
+    elif command == "is_authorized_property":
+        property_type = args.property_type #e.g "email"
+        property_value = args.property_value #e.g test@example.com
+        resources = [IsAuthorizedResource("resourceID", "LabelName"), IsAuthorizedResource("resource2ID", "LabelName")]
+        actions = ["ACTION"]
+        is_authorized = client_authorization.is_authorized_property_filter(property_type, property_value,
+                                                                           resources=resources, actions=actions)
+        if is_authorized:
+            print_response(is_authorized)
+        else:
+            print("Invalid is_authorized")
+        return is_authorized
+
+    elif command == "create_consent":
+        pii_processor_id = args.pii_processor_id
+        pii_principal_id = args.pii_principal_id
+        properties = ["icecream"]
+        consent_response = client.create_consent(pii_processor_id, pii_principal_id, properties)
+        if consent_response:
+            print_response(consent_response)
+        else:
+            print("Invalid consent response")
+        return consent_response
+
+    elif command == "list_consents":
+        pii_principal_id = args.pii_principal_id
+        consent_response = client.list_consents(pii_principal_id)
+        if consent_response:
+            for c in consent_response:
+                print_response(c)
+        else:
+            print("Invalid consent response")
+        return consent_response
+
+    elif command == "revoke_consent":
+        pii_principal_id = args.pii_principal_id
+        consent_ids = args.consent_ids
+        consent_response = client.revoke_consent(pii_principal_id, consent_ids)
+        if consent_response:
+            print_response(consent_response)
+        else:
+            print("Invalid consent response")
+        return consent_response
+
 
 def print_verify_info(digital_twin_info):  # pragma: no cover
     print("Digital twin info")
